@@ -46,6 +46,26 @@ tree.detection.multiple <- function(las.list, id = NULL, file = NULL,
 
   # Tree detection arguments
 
+  if(is.null(tree.detection.arguments$dbh.min)){
+
+    .dbh.min <- 7.5
+
+  } else {
+
+    .dbh.min <- tree.detection.arguments$dbh.min
+
+  }
+
+  if(is.null(tree.detection.arguments$dbh.max)){
+
+    .dbh.max <- 200
+
+  } else {
+
+    .dbh.max <- tree.detection.arguments$dbh.max
+
+  }
+
   if(is.null(tree.detection.arguments$ncr.threshold)){
 
     .ncr.threshold <- 0.1
@@ -69,10 +89,6 @@ tree.detection.multiple <- function(las.list, id = NULL, file = NULL,
 
   for (i in (1:length(las.list))) {
 
-    message("Computing plot: ", i)
-
-    message("Normalizing")
-
     # Assign id
 
     if(!is.null(id)){
@@ -85,6 +101,11 @@ tree.detection.multiple <- function(las.list, id = NULL, file = NULL,
 
     }
 
+    # Messages
+
+    message("Computing plot: ", .id)
+
+    message("Normalizing")
 
     # File name
 
@@ -119,9 +140,9 @@ tree.detection.multiple <- function(las.list, id = NULL, file = NULL,
 
     .tree.list.tls.i <- tree.detection(data = .data,
 
-                                       dbh.min = tree.detection.arguments$dbh.min,
+                                       dbh.min = .dbh.min,
 
-                                       dbh.max = tree.detection.arguments$dbh.max,
+                                       dbh.max = .dbh.max,
 
                                        breaks = .breaks,
 
